# The contents of this file are subject to the Mozilla Public
# License Version 1.1 (the "License"); you may not use this file
# except in compliance with the License. You may obtain a copy of
# the License at http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS
# IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
# implied. See the License for the specific language governing
# rights and limitations under the License.
#
# The Original Code is ManagedMeetings version 1.0.
#
# The Initial Owner of the Original Code is European Environment
# Agency (EEA).  Portions created by CMG and Finsiel Romania are
# Copyright (C) European Environment Agency.  All
# Rights Reserved.
#
# Contributor(s):
# Cornel Nitu, Finsiel Romania
# Rares Vernica, Finsiel Romania

from IEvent import IEvent
from Globals import MessageDialog

import string
from time import *


# QuotedPrintable functions
ESCAPE = '='
MAXLINESIZE = 76
HEX = '0123456789ABCDEF'

def _needsquoting(c):
	"""Decide whether a particular character needs to be quoted."""

	return c == ESCAPE or not(' ' < c <= '~')

def _quote(c):
	"""Quote a single character."""
	i = ord(c)
	if i == 13:
		return ""
	if i == 10:    # Handle UNIX newline
		return ESCAPE + '0D' + ESCAPE + '0A'
	else:
		return ESCAPE + HEX[i/16] + HEX[i%16]

def _qp_encode(line,offset):
	"""Read 'line', apply quoted-printable encoding, and return it.
	"""
	output=''
	if not line:
		return None
	new = ''
	prev = ''
	for c in line:
		if _needsquoting(c):
			c = _quote(c)
		if offset + len(new) + len(c) >= MAXLINESIZE:
			output = output + new + ESCAPE + '\r\n '
			offset = 0
			new = ''
		new = new + c
		prev = c
	if prev in (' ', '\t'):
		output = output + new + ESCAPE + '\r\n'
	else:
		output = output + new + '\r\n'
	return output

def _slash_encode(line,offset):
	"Backslash-escape a string"
	new = ''
	output=''
	for c in line:
		x = c
		if c in [';','\\', ',' ]:
			x = '\\' + c
		if c == '\n':
			x = '\\n'
		if offset + len(new) + len(c) >= MAXLINESIZE:
			output = output + new + '\r\n '
			offset = 0
			new = ''
		new = new + x
	output = output + new + '\r\n'
	return output

class BaseEvent:
    """ BaseEvent class, implements IEvent interface"""

    __implements__=IEvent
		

    def show_vcs(self,REQUEST,RESPONSE):
	"""Generate vCalendar file"""
	RESPONSE.setHeader('Content-Type', 'text/x-vCalendar')
	RESPONSE.setHeader('Content-Disposition', 'attachment; filename="%s.vcs"' % self.id)
	RESPONSE.write("BEGIN:VCALENDAR\r\n")
	RESPONSE.write("PRODID:-//European Environment Agency//Managed Meetings//EN\r\n")
	RESPONSE.write("VERSION:1.0\r\n")
	RESPONSE.write("BEGIN:VEVENT\r\n")
	RESPONSE.write("DTSTART:%s\r\n" % self.startdate.strftime("%Y%m%dT%H%M%S"))
	RESPONSE.write("DTEND:%s\r\n" % self.enddate.strftime("%Y%m%dT%H%M%S"))
	if hasattr(self, "location") and self.location != '' :
	    RESPONSE.write("LOCATION;ENCODING=8-bit:%s\r\n" % self.location)
	elif hasattr(self, "txtlocation") and self.txtlocation!='':
	    RESPONSE.write("LOCATION;ENCODING=8-bit:%s\r\n" % self.txtlocation)
	elif hasattr(self, "urllocation") and self.urllocation!='':
	    RESPONSE.write("LOCATION;ENCODING=8-bit:%s\r\n" % self.urllocation)
	RESPONSE.write("UID:%s\r\n" % REQUEST.URL0)
	RESPONSE.write("URL:%s\r\n" % REQUEST.URL1)
	RESPONSE.write("SUMMARY:%s\r\n" % self.title)	
	if self.description != '':
	    RESPONSE.write("DESCRIPTION;ENCODING=QUOTED-PRINTABLE:%s" % \
	       _qp_encode(self.description,37))
# Check for relative address.
#	if self.agenda_url:
#	    RESPONSE.write("ATTACH;VALUE=URL:%s\r\n" % self.agenda_url)

	for t in self.objectValues(['File', 'DTML Document','Image']):
	    RESPONSE.write("ATTACH;VALUE=URL:%s\r\n" % t.absolute_url())

#	for a in self.objectValues('Meeting Attendee'):
#	    RESPONSE.write("ATTENDEE;ROLE=%s;STATUS=%s:%s %s <%s>\r\n" % \
#		       (a.role, a.attending, a.givenname, a.sn, a.mail))
	RESPONSE.write("END:VEVENT\r\n")
	RESPONSE.write("END:VCALENDAR\r\n")


    def show_ics(self,REQUEST,RESPONSE):
	"""Generate iCalendar file"""
	RESPONSE.setHeader('Content-Type', 'text/calendar')
	RESPONSE.setHeader('Content-Disposition', 'attachment; filename="%s.ics"' % self.id)
	RESPONSE.write("BEGIN:VCALENDAR\r\n")
	RESPONSE.write("PRODID:-//European Environment Agency//Managed Meetings//EN\r\n")
	RESPONSE.write("VERSION:2.0\r\n")
	RESPONSE.write("METHOD:PUBLISH\r\n")
	RESPONSE.write("BEGIN:VEVENT\r\n")
#	for a in self.objectValues('Meeting Attendee'):
#	    RESPONSE.write('ATTENDEE;ROLE=REQ-PARTICIPANT:MAILTO:%s %s <%s>\r\n' % \
#		       ( a.givenname, a.sn, a.mail))
	if self.organiser!='':
		email=''
		if hasattr(self,"organiser_email"):
			email=self.organiser_email
		RESPONSE.write('ORGANIZER;CN="%s":MAILTO="%s"\r\n' % ( self.organiser, email))
	RESPONSE.write("DTSTART:%s\r\n" % self.startdate.strftime("%Y%m%dT%H%M%S"))
	RESPONSE.write("DTEND:%s\r\n" % self.enddate.strftime("%Y%m%dT%H%M%S"))
	if hasattr(self,"location") and self.location != '' :
	    RESPONSE.write('LOCATION;ALTREP="%s/%s":%s\r\n' % \
	     (REQUEST.URL2, self.location, self.location))
	elif hasattr(self,"txtlocation"):
	    RESPONSE.write("LOCATION:%s\r\n" % self.txtlocation)
	elif hasattr(self,"urllocation") and self.urllocation !='' :
	    RESPONSE.write("LOCATION:%s\r\n" % self.urllocation)
	RESPONSE.write("TRANSP:OPAQUE\r\n")
	RESPONSE.write("SEQUENCE:%d\r\n" % self.generation)
 	RESPONSE.write("UID:%s\r\n" % REQUEST.URL0)
 	RESPONSE.write("URL:%s\r\n" % REQUEST.URL1)
	RESPONSE.write("LAST-MODIFIED:%s\r\n" % \
	    self.bobobase_modification_time().toZone('UTC').strftime("%Y%m%dT%H%M%SZ"))

	RESPONSE.write("DTSTAMP:%s\r\n" % \
	    strftime("%Y%m%dT%H%M%SZ",gmtime(time())))
	if self.description != '':
	    RESPONSE.write("DESCRIPTION:%s" % _slash_encode(self.description,12))
 	RESPONSE.write("SUMMARY:%s\r\n" % self.title)	

	RESPONSE.write("PRIORITY:5\r\n")
	RESPONSE.write("CLASS:PUBLIC\r\n")
	RESPONSE.write("END:VEVENT\r\n")
	RESPONSE.write("END:VCALENDAR\r\n")

